@@ -115,12 +115,12 @@ def delete_ldap_group(groupName):
         l.delete_s(dn)
 
 
-def _insert_jos_xgroups(db, name, description, grouptype):
+def _insert_jos_xgroups(db, name, description='', type=0):
         sql =  "INSERT INTO jos_xgroups ( `cn`, `description`, `published`, `type`, `public_desc`, `private_desc`, `restrict_msg`, "
         sql += "`join_policy`, `discussion_email_autosubscribe`, `logo`, `overview_type`, `overview_content`, `plugins`, `created`,"
         sql += "`created_by`, `params`) " 
         sql += "VALUES (" + '%s,'*15 + "%s );" 
-        data = (name, description, 0, int(grouptype), '', '', '', 1, 0, '', None, None, None, datetime.datetime.now(), None, None)
+        data = (name, description, 0, int(type), '', '', '', 1, 0, '', None, None, None, datetime.datetime.now(), None, None)
 
         gidNumber = db.query_lastrowid(sql, data)
 
@@ -159,7 +159,7 @@ def delhubgroup(groupName):
         _del_jos_xgroups(db, groupName)
 
 
-def addhubgroup(groupName, groupDescription):
+def addhubgroup(groupName, description='', type=0):
 
         # grab config options
         dbPW = hubzero.config.webconfig.getWebConfigDBPassword()
@@ -167,9 +167,9 @@ def addhubgroup(groupName, groupDescription):
         dbName = hubzero.config.webconfig.getWebConfigDBName()
         db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
 
-        gidNumber = _insert_jos_xgroups(db, groupName, groupDescription)
+        gidNumber = _insert_jos_xgroups(db, groupName, description, type)
 
-        add_ldap_group(groupName, groupDescription, gidNumber)
+        add_ldap_group(groupName, description, gidNumber)
 
         return gidNumber	
 
